Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(155)

Unified Diff: chrome/browser/chromeos/policy/device_cloud_policy_manager_chromeos.cc

Issue 2534433002: Mop up incorrect uses of IsEnterpriseManaged() (Closed)
Patch Set: Address Roman's comment Created 4 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/chromeos/policy/device_cloud_policy_manager_chromeos.cc
diff --git a/chrome/browser/chromeos/policy/device_cloud_policy_manager_chromeos.cc b/chrome/browser/chromeos/policy/device_cloud_policy_manager_chromeos.cc
index 7de9637274bf6bcb2fe6bd751f915f20d6730a3c..d64288aa18b8a5c44f6ce22106355cb9bcb9fca1 100644
--- a/chrome/browser/chromeos/policy/device_cloud_policy_manager_chromeos.cc
+++ b/chrome/browser/chromeos/policy/device_cloud_policy_manager_chromeos.cc
@@ -265,12 +265,12 @@ void DeviceCloudPolicyManagerChromeOS::StartConnection(
attestation_policy_observer_.reset(
new chromeos::attestation::AttestationPolicyObserver(client()));
- // Enable device reporting and status monitoring for enterprise enrolled
- // devices. We want to create these objects for enrolled devices, even if
- // monitoring is currently inactive, in case monitoring is turned back on in
- // a future policy fetch - the classes themselves track the current state of
- // the monitoring settings and only perform monitoring if it is active.
- if (install_attributes->IsEnterpriseManaged()) {
+ // Enable device reporting and status monitoring for cloud managed devices. We
+ // want to create these objects even if monitoring is currently inactive, in
+ // case monitoring is turned back on in a future policy fetch - the classes
+ // themselves track the current state of the monitoring settings and only
+ // perform monitoring if it is active.
+ if (install_attributes->IsCloudManaged()) {
CreateStatusUploader();
syslog_uploader_.reset(new SystemLogUploader(nullptr, task_runner_));
heartbeat_scheduler_.reset(new HeartbeatScheduler(

Powered by Google App Engine
This is Rietveld 408576698